#
# spec file for package obexftp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obexftp
Version:        0.24.2
Release:        3.1
Summary:        ObexFTP Implements the Object Exchange (OBEX) Protocol's File Transfer Feature
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://triq.net/obexftp
Source:         https://sourceforge.net/projects/openobex/files/obexftp/%{version}/obexftp-%{version}-Source.tar.gz
Patch0:         obexftp-0.24-fix-absurd-install-path.patch
Patch1:         obexftp-0.24-move_to_python3.patch
BuildRequires:  asciidoc
BuildRequires:  bluez-devel
BuildRequires:  cmake
# support for building obexfs from this source is disabled for now. reenable ASAP
#BuildRequires:  fuse-devel
BuildRequires:  libtool
BuildRequires:  openobex-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  ruby-devel
BuildRequires:  swig
BuildRequires:  xmlto

%description
ObexFTP works with all protocols supported by openobex (OpenOBEX).
Currently, these are:

- irda (IrDA),
- bluez-utils (BlueTooth)
- setserial (Serial)

%package devel
Summary:        Development package for obexftp
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       openobex-devel

%description devel
Files needed for software development using obexftp.

%prep
%setup -q -n %{name}-%{version}-Source
%patch -P 0 -p1
%patch -P 1

chmod -x AUTHORS Doxyfile ChangeLog NEWS README THANKS TODO examples/README_obexftpbackup

%build
# Remove cmake4 error due to not setting
# min cmake version - sflees.de
export CMAKE_POLICY_VERSION_MINIMUM=3.5
mkdir build
cd build
# FIXME: you should use the %%cmake macros
cmake -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} ..
%make_build all doc # because "all" apparently does not mean "all"

%install
cd build
make "DESTDIR=$RPM_BUILD_ROOT" install

%perl_process_packlist
find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%{_bindir}/*
%{_libdir}/lib*.so.*
%{_mandir}/*/*

%files devel
%{_libdir}/lib*.so
%{_includedir}/bfb
%{_includedir}/obexftp
%{_includedir}/multicobex
%{_libdir}/pkgconfig/obexftp.pc

%package -n python3-obexftp
Summary:        ObexFTP Implements the Object Exchange (OBEX) - Python3 bindings
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description -n python3-obexftp
ObexFTP works out-of-the-box with all protocols supported by OpenOBEX.
Currently IrDA, BlueTooth, and Serial.

This package contains the python3 bindings.

%files -n python3-obexftp
%{python3_sitearch}/*

%package -n perl-obexftp
Summary:        ObexFTP Implements the Object Exchange (OBEX) - Perl bindings
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}
Requires:       perl-base = %{perl_version}

%description -n perl-obexftp
ObexFTP works out-of-the-box with all protocols supported by OpenOBEX.
Currently IrDA, BlueTooth, and Serial.

This package contains the Perl bindings.

%files -n perl-obexftp
%if 0%{?suse_version} < 1140
%{_localstatedir}/adm/perl-modules/obexftp
%endif
%{perl_vendorarch}/OBEXFTP.pm
%{perl_vendorarch}/auto/OBEXFTP

%package -n ruby-obexftp
Summary:        ObexFTP Implements the Object Exchange (OBEX) - Ruby bindings
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}
Requires:       ruby(abi) = %{rb_ver}

%description -n ruby-obexftp
ObexFTP works out-of-the-box with all protocols supported by OpenOBEX.
Currently IrDA, BlueTooth, and Serial.

This package contains the Ruby bindings.

%files -n ruby-obexftp
%{_libdir}/ruby/vendor_ruby/%{rb_ver}/%{rb_arch}/obexftp.so

%changelog
* Wed May  7 2025 Simon Lees <sflees@suse.de>
- export CMAKE_POLICY_VERSION_MINIMUM="3.5" to ignore cmakes
  minimum version warnings
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.24.2:
  * obexfs: Parse XML data with Expat library
  * obexfs: Properly encode XML special characters
  * obexfs: New option -r to specify root path
  * obexfs: New option -S to simulate free space
  * Fix probing
  * Add support for Gigaset devices
  * CMake improvements
  * Fix build system bugs
  * Replace CRC implementation in libbfb
- remove obexftp-pkgconfig_requires.patch : upstream
* Fri May 15 2020 ldreier@vodafonemail.de
- Build python bindings for python3 instead of for python2
- Add obexftp-0.24-move_to_python3.patch:
  Use PyUnicode_FromStringAndSize instead of
  PyString_FromStringAndSize in swig/charmap.i (needed for python3)
* Tue Nov 19 2013 ro@suse.de
- obexftp-pkgconfig_requires.patch:
  in pkgconfig file, require bluez instead of bluetooth
* Wed Oct 16 2013 jmatejek@suse.com
- update to 0.24
  * new upstream maintainer
  * integrates obexfs 0.12 (build disabled for now)
  * includes Ruby binding
  * builds with OpenOBEX 1.7
  * build system is now based on CMake
- patch obexftp-0.24-fix-absurd-install-path - install Python binding
  into the correct location
- dropped gcc43.diff - no longer necessary
* Thu May 24 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Jan 14 2011 coolo@novell.com
- fix build on 11.4
* Mon Apr 26 2010 ro@suse.de
- update to 0.23
  * allow win32 to use hci src names
  * adding a simpler connect wrapper
  * show OBEX_HandleInput errors
  * catch errors and let the user know
  * print timeout stats if available
  * sdp unregister more verbose
  * upgrading btkit
  * fix for win32 without bt
  * replacing deprecated automake vars
  * sizeof() fixes
  * removing bdaddr_t reference from obexftpd.c
  * adding bootstrap helper
  * concurrency bug in extconf.rb generated Makefile (fix by Alin Năstac)
  * switching from POD to asciidoc
  * clearing gnu-style implicit rules
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Sep 16 2008 ro@suse.de
- fix requires for devel package
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Tue Jun 24 2008 dmueller@suse.de
- update to 0.22:
  * for changelog, see included ChangeLog
* Thu Jun 21 2007 dmueller@suse.de
- split off perl- and python- bindings to remove
  python depenceny from main package
* Fri May 18 2007 olh@suse.de
- remove unneeded libusb from -devel Requires
* Mon May  7 2007 sbrabec@suse.cz
- Fixed LDFLAGS to include needed libraries explicitly.
* Sun Apr 22 2007 dgollub@suse.de
- Make use of LIBADD instead of LDADD.
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Wed Jun 28 2006 cthiel@suse.de
- update to version 0.21
  * Fixes to obexftpd
  * Added ruby binding
  * Added preliminary discovery function
* Tue Jun 27 2006 cthiel@suse.de
- update to version 0.20
  * Change __S_IFDIR to S_IFDIR with fallback sug.
  * Added old CLI switches and documentation sug.
  * Fixed the -g CLI switch
  * Added obexfsd
  * Fixed iconv
  * device/channel code cleanup
* Sun Apr 23 2006 cthiel@suse.de
- update to version 0.19
  * Updated for OpenOBEX 1.1 (pkg-config)
  * Added --output switch
  * Simplified the swig/perl/Makefile.am.
  * Fixed a pointer typo and a free() typo.
  * Added perl, python and tcl binding with swig.
  * Rewrote folder-listing parser to enhance compatibility
  * Connection headers
  * Nokia hack (suppressing FBS)
  * Capabilty retrieving
  * USB support
  * Added implicit setpath support in every function.
  * Added simple caching
  * Removed recursive put. Apps should implement it themselves.
  * New configure flag to enable building docs
  * Documentation updated
- dropped obexftp-irda.patch
- dropped obexftp-noxml.patch
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug 23 2005 hvogel@suse.de
- update to version 0.10.7
* Mon Sep  6 2004 hvogel@suse.de
- make irda work again [Bug #43363]
* Thu Feb 12 2004 hvogel@suse.de
- update to version 0.10.4rc3
- split into main package and -devel
- spec file clean up
- include more documentation
* Thu Jan 29 2004 hvogel@suse.de
- mark man pages as documentation
* Tue Jan 27 2004 ro@suse.de
- added openobex-devel to neededforbuild
* Fri Jan 16 2004 meissner@suse.de
- Initial version 0.10.3.
